local mod = ...



-- Custom Component: Random Events -------------------------------------------------------------------------------------
local COMP_TAS_EVENT = {
	TypeName = "COMP_TAS_EVENT",
	ParentType = "COMPONENT",
	Properties = {
        {
            Name = "DayLastEvent",
            Type = "integer",
            Default = 0,
            Flags = { "SAVE_GAME" }
        },
		{
            Name = "EventTracker",
            Type = "list<vec2i>",
            Default = { 
                {1, 0},
                {2, 0},
                {3, 0},
                {4, 0},
                {5, 0},
                {6, 0},
                {7, 0},
                {8, 0},
                {9, 0},
                {10, 0},
                {11, 0},
                {12, 0},
                {13, 0},
                {14, 0},
                {15, 0},
                {16, 0},
                {17, 0},
                {18, 0},
                {19, 0},
                {20, 0},
                {21, 0},
                {22, 0},
                {23, 0},
                {24, 0},
                {25, 0},
                {26, 0},
                {27, 0},
                {28, 0},
                {29, 0},
                {30, 0},
                {31, 0},
                {32, 0},
                {33, 0},
                {34, 0},
                {35, 0},
                {36, 0},
                {37, 0},
                {38, 0},
                {39, 0},
                {40, 0},
                {41, 0},
                {42, 0},
                {43, 0},
                {44, 0},
                {45, 0},
                {46, 0},
                {47, 0},
                {48, 0},
                {49, 0},
                {50, 0},
            },
            Flags = { "SAVE_GAME" }
        },
    }
}



-- Register custom Class
mod:registerClass(COMP_TAS_EVENT)



-- Attach class to the prefab manager which means it will be present in the game from the beginning
mod:registerPrefabComponent("PREFAB_MANAGER", { DataType = "COMP_TAS_EVENT" } )



-- Loop through all events and create: Job, Quest, Event
for i=1, 47, 1 do

    -- Job: Event Trigger -------------------------------------------------------------------------------------
    mod:register({
        DataType = "JOB",
        Id = "JOB_TAS_EVENT_" .. string.sub("000" .. i, -3),
        JobName = "JOB_TAS_EVENT_NAME",
        JobDescription = "JOB_TAS_EVENT_DESC",
        IsLockedByDefault = true,
        Hidden = true,
        DefaultBehavior = "BEHAVIOR_WORK",
        ProductionDelay = 0.0, -- default 30
        AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
        CharacterSetup = {
            DataType = "CHARACTER_SETUP",
            IdleAnimation = "IDLE"
        }
    })

    mod:override({
        Id = "NEWCOMER",
        CompatibleJobList = {
            Action = "APPEND",
            "JOB_TAS_EVENT_" .. string.sub("000" .. i, -3)
        }
    })

    mod:override({
        Id = "SERF",
        CompatibleJobList = {
            Action = "APPEND",
            "JOB_TAS_EVENT_" .. string.sub("000" .. i, -3)
        }
    })

    mod:override({
        Id = "COMMONER",
        CompatibleJobList = {
            Action = "APPEND",
            "JOB_TAS_EVENT_" .. string.sub("000" .. i, -3)
        }
    })

    mod:override({
        Id = "CITIZEN",
        CompatibleJobList = {
            Action = "APPEND",
            "JOB_TAS_EVENT_" .. string.sub("000" .. i, -3)
        }
    })


    -- Quest ---------------------------------------------------------------------------------------------
    mod:register({
        DataType = "QUEST",
        Id = "QUEST_TAS_EVENT_" .. string.sub("000" .. i, -3),
        Name = "QUEST_TAS_EVENT_NAME",
        Description = "QUEST_TAS_EVENT_DESC",
        IsSilent = true,
        QuestFunction = {
            DataType = "QUEST_FUNCTION_ASSIGN_WORKER",
            Job = "JOB_TAS_EVENT_" .. string.sub("000" .. i, -3)
        },
        QuestRewardList = nil,
        QuestFailList = nil,
        QuestListToUnlockAfter = nil,
        OnFailCallback = nil,
        OnSuccessCallback = {
            DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
            Event = "EVENT_TAS_EVENT_" .. string.sub("000" .. i, -3)
        }
    })


    -- Default Balancing (event list) ---------------------------------------------------------------------------------------------
    mod:override({
        Id = "DEFAULT_BALANCING",
        EventList = {
            Action = "APPEND", 
            "EVENT_TAS_EVENT_SETUP_" .. string.sub("000" .. i, -3),
        },
    })


    -- Event: Setup ---------------------------------------------------------------------------------------------
    mod:register({
        DataType = "EVENT",
        Id = "EVENT_TAS_EVENT_SETUP_" .. string.sub("000" .. i, -3),
        Title = "EVENT_TAS_EVENT_SETUP_TITLE",
        Description = "EVENT_TAS_EVENT_SETUP_DESC",
        IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
        IsRecurrent = false,
        DaysToFirst = 1, -- number of days from the start of the game (setting = 5 will fire the event at the start of Day 5). 
        ConditionList = {
            {
                DataType = "EVENT_CONDITION_BUILDING_BUILT",
                AssetBuilding = "BUILDING_VILLAGE_CENTER"
            }
        },
        ActionList = {
            {
                DataType = "EVENT_ACTION_GIVE_QUEST",
                Quest = "QUEST_TAS_EVENT_" .. string.sub("000" .. i, -3)
            },
        }
    })

end



-- Event: 001 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event001.png", "TEXTURE_TAS_EVENT001")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_001",
    Title = "EVENT_TAS_EVENT_001_TITLE",
	Description = "EVENT_TAS_EVENT_001_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_001_TITLE",
                Description = "EVENT_TAS_EVENT_001_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT001"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_001_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "BERRIES",
                                        },
                                        YieldPercentage = 0.1,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_001"
                                }
                            }
                        },
                     },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_001"
        },
    }
})



-- Event: 002 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event002.png", "TEXTURE_TAS_EVENT002")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_002",
    Title = "EVENT_TAS_EVENT_002_TITLE",
	Description = "EVENT_TAS_EVENT_002_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_002_TITLE",
                Description = "EVENT_TAS_EVENT_002_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT002"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_002_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "RESOURCE_FRUIT",
                                        },
                                        YieldPercentage = 0.1,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_002"
                                }
                            }
                        },
                     },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_002"
        },
    }
})



-- Event: 003 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event003.png", "TEXTURE_TAS_EVENT003")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_003",
    Title = "EVENT_TAS_EVENT_003_TITLE",
	Description = "EVENT_TAS_EVENT_003_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_003_TITLE",
                Description = "EVENT_TAS_EVENT_003_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT003"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_003_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "WHEAT",
                    Quantity = 1000000
                },
                {
                    Resource = "FLOUR",
                    Quantity = 1000000
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_003"
        },
    }
})



-- Event: 004 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event004.png", "TEXTURE_TAS_EVENT004")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_004",
    Title = "EVENT_TAS_EVENT_004_TITLE",
	Description = "EVENT_TAS_EVENT_004_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_004_TITLE",
                Description = "EVENT_TAS_EVENT_004_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT004"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_004_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_PAY",
            AmountToPay = {
                {
                    Resource = "CLOTHES",
                    Quantity = 1000000
                },
                {
                    Resource = "RESOURCE_FURNITURE",
                    Quantity = 1000000
                },
            }
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_004"
        },
    }
})



-- Event: 005 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event005.png", "TEXTURE_TAS_EVENT005")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_005",
    Title = "EVENT_TAS_EVENT_005_TITLE",
	Description = "EVENT_TAS_EVENT_005_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_005_TITLE",
                Description = "EVENT_TAS_EVENT_005_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT005"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_005_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "RESOURCE_VEGETABLE",
                                        },
                                        YieldPercentage = 3.0,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_005"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_005"
        },
    }
})



-- Event: 006 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event006.png", "TEXTURE_TAS_EVENT006")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_006",
    Title = "EVENT_TAS_EVENT_006_TITLE",
	Description = "EVENT_TAS_EVENT_006_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_006_TITLE",
                Description = "EVENT_TAS_EVENT_006_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT006"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_006_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "RESOURCE_VEGETABLE",
                                        },
                                        YieldPercentage = 0.25,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_006"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_006"
        },
    }
})



-- Event: 007 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event007.png", "TEXTURE_TAS_EVENT007")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_007",
    Title = "EVENT_TAS_EVENT_007_TITLE",
	Description = "EVENT_TAS_EVENT_007_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_007_TITLE",
                Description = "EVENT_TAS_EVENT_007_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT007"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_007_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "FISH",
                                        },
                                        YieldPercentage = 0.1,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_007"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_007"
        },
    }
})



-- Event: 008 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event008.png", "TEXTURE_TAS_EVENT008")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_008",
    Title = "EVENT_TAS_EVENT_008_TITLE",
	Description = "EVENT_TAS_EVENT_008_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_008_TITLE",
                Description = "EVENT_TAS_EVENT_008_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT008"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_008_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "RESOURCE_POULTRY",
                                            "BV1_EGG",
                                        },
                                        YieldPercentage = 0.5,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_008"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_008"
        },
    }
})



-- Event: 009 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event009.png", "TEXTURE_TAS_EVENT009")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_009",
    Title = "EVENT_TAS_EVENT_009_TITLE",
	Description = "EVENT_TAS_EVENT_009_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_009_TITLE",
                Description = "EVENT_TAS_EVENT_009_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT009"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_009_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "MILK",
                                        },
                                        YieldPercentage = 0.25,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_009"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_009"
        },
    }
})



-- Event: 010 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event010.png", "TEXTURE_TAS_EVENT010")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_010",
    Title = "EVENT_TAS_EVENT_010_TITLE",
	Description = "EVENT_TAS_EVENT_010_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_010_TITLE",
                Description = "EVENT_TAS_EVENT_010_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT010"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_010_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_RESOURCES",
                                    ResourceCollection = {
                                        {
                                            Resource = "WOOL",
                                            Quantity = 100
                                        },
                                    }
                                },
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "WOOL",
                                        },
                                        YieldPercentage = 0.25,
                                        IsUntilRemoval = false, 
                                        IsGlobal = true, 
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_010"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_010"
        },
    }
})



-- Event: 011 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event011.png", "TEXTURE_TAS_EVENT011")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_011",
    Title = "EVENT_TAS_EVENT_011_TITLE",
	Description = "EVENT_TAS_EVENT_011_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_011_TITLE",
                Description = "EVENT_TAS_EVENT_011_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT011"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_011_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "MILK",
                                            "WOOL",
                                            "RESOURCE_CATTLE",
                                            "RESOURCE_PIG",
                                            "RESOURCE_SHEEP",
                                            "RESOURCE_GOAT",
                                        },
                                        YieldPercentage = 0.25,
                                        IsUntilRemoval = false, 
                                        IsGlobal = true, 
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_011"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_011"
        },
    }
})



-- Event: 012 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event012.png", "TEXTURE_TAS_EVENT012")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_012",
    Title = "EVENT_TAS_EVENT_012_TITLE",
	Description = "EVENT_TAS_EVENT_012_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_012_TITLE",
                Description = "EVENT_TAS_EVENT_012_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT012"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_012_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_NEED_TYPE_DEPLETE_RATE",
                                        NeedType = "NEED_SERVICE",
                                        BonusInPerc = 4.0,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 84
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_012"
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_012"
        },
    }
})



-- Event: 013 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event013.png", "TEXTURE_TAS_EVENT013")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_013",
    Title = "EVENT_TAS_EVENT_013_TITLE",
	Description = "EVENT_TAS_EVENT_013_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_013_TITLE",
                Description = "EVENT_TAS_EVENT_013_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT013"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_013_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_NEED_TYPE_DEPLETE_RATE",
                                        NeedType = "NEED_LUXURY",
                                        BonusInPerc = 4.0,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_013"
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_013"
        },
    }
})



-- Event: 014 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event014.png", "TEXTURE_TAS_EVENT014")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_014",
    Title = "EVENT_TAS_EVENT_014_TITLE",
	Description = "EVENT_TAS_EVENT_014_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_014_TITLE",
                Description = "EVENT_TAS_EVENT_014_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT014"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_014_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_PAY",
                            AmountToPay = {
                                {
                                    Resource = "GOLD_COINS",
                                    Quantity = 1000
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_014"
        },
    }
})



-- Event: 015 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event015.png", "TEXTURE_TAS_EVENT015")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_015",
    Title = "EVENT_TAS_EVENT_015_TITLE",
	Description = "EVENT_TAS_EVENT_015_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_015_TITLE",
                Description = "EVENT_TAS_EVENT_015_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT015"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_015_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_RESOURCES",
                                    ResourceCollection = {
                                        {
                                            Resource = "GOLD_COINS",
                                            Quantity = 2000
                                        },
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_015"
        },
    }
})



-- Event: 016 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event016.png", "TEXTURE_TAS_EVENT016")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_016",
    Title = "EVENT_TAS_EVENT_016_TITLE",
	Description = "EVENT_TAS_EVENT_016_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_016_TITLE",
                Description = "EVENT_TAS_EVENT_016_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT016"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_016_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_RESOURCES",
                                    ResourceCollection = {
                                        {
                                            Resource = "GOLD_COINS",
                                            Quantity = 1500
                                        },
                                    }
                                },
                                {
                                    DataType = "QUEST_REWARD_IMMIGRATION_WAVE"
                                },
                                {
                                    DataType = "QUEST_REWARD_IMMIGRATION_WAVE"
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_016"
        },
    }
})



-- Event: 017 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event017.png", "TEXTURE_TAS_EVENT017")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_017",
    Title = "EVENT_TAS_EVENT_017_TITLE",
	Description = "EVENT_TAS_EVENT_017_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_017_TITLE",
                Description = "EVENT_TAS_EVENT_017_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT017"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_017_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_RESOURCES",
                                    ResourceCollection = {
                                        {
                                            Resource = "GOLD_COINS",
                                            Quantity = 250
                                        },
                                        {
                                            Resource = "SWORD",
                                            Quantity = 10
                                        },
                                        {
                                            Resource = "SPEAR",
                                            Quantity = 5
                                        },
                                        {
                                            Resource = "JEWELRY",
                                            Quantity = 20
                                        },
                                        {
                                            Resource = "GEMS",
                                            Quantity = 5
                                        },
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_017"
        },
    }
})



-- Event: 018 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event018.png", "TEXTURE_TAS_EVENT018")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_018",
    Title = "EVENT_TAS_EVENT_018_TITLE",
	Description = "EVENT_TAS_EVENT_018_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_018_TITLE",
                Description = "EVENT_TAS_EVENT_018_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT018"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_018_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_INFLUENCE",
                                    EstateInfluence = {
                                        Estate = "KINGDOM",
                                        Quantity = 10
                                    }
                                },
                                {
                                    DataType = "QUEST_REWARD_RESOURCES",
                                    ResourceCollection = {
                                        {
                                            Resource = "GOLD_COINS",
                                            Quantity = 500
                                        },
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_018_CHOICE_2",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_RESOURCES",
                                    ResourceCollection = {
                                        {
                                            Resource = "GEMS",
                                            Quantity = 20
                                        },
                                    }
                                },
                                {
                                    DataType = "QUEST_REWARD_INFLUENCE",
                                    EstateInfluence = {
                                        Estate = "KINGDOM",
                                        Quantity = -20
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_018"
        },
    }
})



-- Event: 019 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event019.png", "TEXTURE_TAS_EVENT019")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_019",
    Title = "EVENT_TAS_EVENT_019_TITLE",
	Description = "EVENT_TAS_EVENT_019_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_019_TITLE",
                Description = "EVENT_TAS_EVENT_019_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT019"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_019_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_PAY",
                            AmountToPay = {
                                {
                                    Resource = "GOLD_COINS",
                                    Quantity = 2500
                                },
                            }
                        },
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "FLOUR",
                                            "BREAD",
                                            "BEER",
                                            "WINE",
                                            "CHEESE",
                                            "WOOLEN_CLOTH",
                                            "CLOTHES",
                                            "TOOL",
                                            "IRON",
                                            "GLASS",
                                            "GOLD_BARS",
                                            "JEWELRY",
                                        },
                                        YieldPercentage = 0.795,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 28
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_019"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_019_CHOICE_2",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "FLOUR",
                                            "BREAD",
                                            "BEER",
                                            "WINE",
                                            "CHEESE",
                                            "WOOLEN_CLOTH",
                                            "CLOTHES",
                                            "TOOL",
                                            "IRON",
                                            "GLASS",
                                            "GOLD_BARS",
                                            "JEWELRY",
                                        },
                                        YieldPercentage = 0.20,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 28
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_019"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_019"
        },
    }
})



-- Event: 020 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event020.png", "TEXTURE_TAS_EVENT020")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_020",
    Title = "EVENT_TAS_EVENT_020_TITLE",
	Description = "EVENT_TAS_EVENT_020_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_020_TITLE",
                Description = "EVENT_TAS_EVENT_020_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT020"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_020_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "WHEAT",
                                            "MILK",
                                            "WOOL",
                                            "HOP",
                                            "RESOURCE_VEGETABLE",
                                            "RESOURCE_FRUIT",
                                            "RESOURCE_POULTRY",
                                            "BV1_EGG",
                                            "BV1_MEAT",
                                        },
                                        YieldPercentage = 0.795,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 28
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_020"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_020_CHOICE_2",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_PAY",
                            AmountToPay = {
                                {
                                    Resource = "WHEAT",
                                    Quantity = 100
                                },
                                {
                                    Resource = "MILK",
                                    Quantity = 100
                                },
                                {
                                    Resource = "WOOL",
                                    Quantity = 100
                                },
                                {
                                    Resource = "HOP",
                                    Quantity = 100
                                },
                                {
                                    Resource = "RESOURCE_VEGETABLE",
                                    Quantity = 100
                                },
                                {
                                    Resource = "RESOURCE_FRUIT",
                                    Quantity = 100
                                },
                                {
                                    Resource = "RESOURCE_POULTRY",
                                    Quantity = 100
                                },
                                {
                                    Resource = "BV1_EGG",
                                    Quantity = 100
                                },
                                {
                                    Resource = "BV1_MEAT",
                                    Quantity = 100
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_020"
        },
    }
})



-- Event: 021 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event021.png", "TEXTURE_TAS_EVENT021")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_021",
    Title = "EVENT_TAS_EVENT_021_TITLE",
	Description = "EVENT_TAS_EVENT_021_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_021_TITLE",
                Description = "EVENT_TAS_EVENT_021_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT021"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_021_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_TERRITORY",
                                    Amount = 2
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_021_CHOICE_2",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_INFLUENCE",
                                    EstateInfluence = {
                                        Estate = "KINGDOM",
                                        Quantity = -20
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_021"
        },
    }
})



-- Event: 022 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event022.png", "TEXTURE_TAS_EVENT022")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_022",
    Title = "EVENT_TAS_EVENT_022_TITLE",
	Description = "EVENT_TAS_EVENT_022_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_022_TITLE",
                Description = "EVENT_TAS_EVENT_022_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT022"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_022_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_IMMIGRATION_WAVE",
                                },
                                {
                                    DataType = "QUEST_REWARD_IMMIGRATION_WAVE",
                                },
                                {
                                    DataType = "QUEST_REWARD_IMMIGRATION_WAVE",
                                },
                                {
                                    DataType = "QUEST_REWARD_IMMIGRATION_WAVE",
                                },
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_IMMIGRATION_RATE",
                                        QuantityToAdd = 4,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 28
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_022"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_022_CHOICE_2",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_INFLUENCE",
                                    EstateInfluence = {
                                        Estate = "LABOUR",
                                        Quantity = -20
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_022"
        },
    }
})



-- Event: 023 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event023.png", "TEXTURE_TAS_EVENT023")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_023",
    Title = "EVENT_TAS_EVENT_023_TITLE",
	Description = "EVENT_TAS_EVENT_023_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_023_TITLE",
                Description = "EVENT_TAS_EVENT_023_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT023"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_023_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_QUEST",
                            Quest = "QUEST_TAS_EVENT_023_RESPOND"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_023"
        },
    }
})

-- Quest ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_EVENT_023_RESPOND",
    Name = "QUEST_TAS_EVENT_023_RESPOND_NAME",
    Description = "QUEST_TAS_EVENT_023_RESPOND_DESC",
    IsSilent = false,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_DELIVER_RESOURCES", 
        Estate = "LABOUR",
        ResourceListToDeliver = {
            { 
                Resource = "WHEAT",
                Quantity = 200
            },
        },
        DaysCount = 14
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_INFLUENCE",
            EstateInfluence = {
                Estate = "LABOUR",
                Quantity = 20
            }
        },
    },
    QuestFailList = {
        {
            DataType = "QUEST_REWARD_INFLUENCE",
            EstateInfluence = {
                Estate = "LABOUR",
                Quantity = -20
            }
        },
    },
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})



-- Event: 024 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event024.png", "TEXTURE_TAS_EVENT024")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_024",
    Title = "EVENT_TAS_EVENT_024_TITLE",
	Description = "EVENT_TAS_EVENT_024_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_024_TITLE",
                Description = "EVENT_TAS_EVENT_024_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT024"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_024_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "MILK",
                                            "WOOL",
                                            "RESOURCE_POULTRY",
                                            "BV1_EGG",
                                            "RESOURCE_CATTLE",
                                            "RESOURCE_PIG",
                                            "RESOURCE_SHEEP",
                                            "RESOURCE_GOAT",
                                        },
                                        YieldPercentage = 0.595,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_024"
                                },
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "MILK",
                                            "WOOL",
                                            "RESOURCE_POULTRY",
                                            "BV1_EGG",
                                            "BV1_MEAT",
                                        },
                                        YieldPercentage = 1.20,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 336
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_024"
                                }
                            }
                        },
                    },
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_024"
        },
    }
})



-- Event: 025 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event025.png", "TEXTURE_TAS_EVENT025")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_025",
    Title = "EVENT_TAS_EVENT_025_TITLE",
	Description = "EVENT_TAS_EVENT_025_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_025_TITLE",
                Description = "EVENT_TAS_EVENT_025_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT025"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_025_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_NEED_TYPE_DEPLETE_RATE",
                                        NeedType = "NEED_HOUSE_LEVEL_1",
                                        BonusInPerc = 2.0,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_SETUP_025"
                                },
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_NEED_TYPE_DEPLETE_RATE",
                                        NeedType = "NEED_HOUSE_LEVEL_2",
                                        BonusInPerc = 2.0,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_SETUP_025"
                                },
                            }
                        },
                    },
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_025"
        },
    }
})



-- Event: 026 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event026.png", "TEXTURE_TAS_EVENT026")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_026",
    Title = "EVENT_TAS_EVENT_026_TITLE",
	Description = "EVENT_TAS_EVENT_026_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_026_TITLE",
                Description = "EVENT_TAS_EVENT_026_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT026"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_026_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "WHEAT",
                                            "RESOURCE_VEGETABLE",
                                        },
                                        YieldPercentage = 1.25,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_026"
                                },
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "FISH",
                                        },
                                        YieldPercentage = 0.749,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_026"
                                },
                            }
                        },
                    },
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_026"
        },
    }
})



-- Event: 027 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event027.png", "TEXTURE_TAS_EVENT027")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_027",
    Title = "EVENT_TAS_EVENT_027_TITLE",
	Description = "EVENT_TAS_EVENT_027_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_027_TITLE",
                Description = "EVENT_TAS_EVENT_027_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT027"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_027_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_QUEST",
                            Quest = "QUEST_TAS_EVENT_027_RESPOND"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_027"
        },
    }
})

-- Quest ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_EVENT_027_RESPOND",
    Name = "QUEST_TAS_EVENT_027_RESPOND_NAME",
    Description = "QUEST_TAS_EVENT_027_RESPOND_DESC",
    IsSilent = false,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_DELIVER_RESOURCES", 
        Estate = "LABOUR",
        ResourceListToDeliver = {
            { 
                Resource = "WHEAT",
                Quantity = 100
            },
            { 
                Resource = "BREAD",
                Quantity = 20
            },
            { 
                Resource = "BERRIES",
                Quantity = 40
            },
        },
        DaysCount = 28
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_RESOURCES",
            ResourceCollection = {
                {
                    Resource = "TOOL",
                    Quantity = 50
                },
            }
        },
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})



-- Event: 028 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event028.png", "TEXTURE_TAS_EVENT028")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_028",
    Title = "EVENT_TAS_EVENT_028_TITLE",
	Description = "EVENT_TAS_EVENT_028_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_028_TITLE",
                Description = "EVENT_TAS_EVENT_028_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT028"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_028_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_QUEST",
                            Quest = "QUEST_TAS_EVENT_028_RESPOND"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_028"
        },
    }
})

-- Quest ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_EVENT_028_RESPOND",
    Name = "QUEST_TAS_EVENT_028_RESPOND_NAME",
    Description = "QUEST_TAS_EVENT_028_RESPOND_DESC",
    IsSilent = false,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_BUILD", 
        BuildingListToBuild = {
            "BUILDING_CHEESE_MAKER",
        }
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "CHEESE",
                },
                YieldPercentage = 1.25,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 336
            },
            OptionalApplicator = "EVENT_TAS_EVENT_028"
        },
        {
            DataType = "QUEST_REWARD_IMMIGRATION_WAVE"
        },
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})



-- Event: 029 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event029.png", "TEXTURE_TAS_EVENT029")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_029",
    Title = "EVENT_TAS_EVENT_029_TITLE",
	Description = "EVENT_TAS_EVENT_029_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_029_TITLE",
                Description = "EVENT_TAS_EVENT_029_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT029"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_029_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_QUEST",
                            Quest = "QUEST_TAS_EVENT_029_RESPOND"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_029"
        },
    }
})

-- Quest ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_EVENT_029_RESPOND",
    Name = "QUEST_TAS_EVENT_029_RESPOND_NAME",
    Description = "QUEST_TAS_EVENT_029_RESPOND_DESC",
    IsSilent = false,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_DELIVER_RESOURCES", 
        Estate = "LABOUR",
        ResourceListToDeliver = {
            { 
                Resource = "BREAD",
                Quantity = 100
            },
            { 
                Resource = "BERRIES",
                Quantity = 40
            },
        },
        DaysCount = 28
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "PLANK",
                    "RESOURCE_SHINGLE",
                    "RESOURCE_FURNITURE",
                },
                YieldPercentage = 1.25,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 336
            },
            OptionalApplicator = "EVENT_TAS_EVENT_029"
        },
        {
            DataType = "QUEST_REWARD_IMMIGRATION_WAVE"
        },
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})



-- Event: 030 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event030.png", "TEXTURE_TAS_EVENT030")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_030",
    Title = "EVENT_TAS_EVENT_030_TITLE",
	Description = "EVENT_TAS_EVENT_030_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_030_TITLE",
                Description = "EVENT_TAS_EVENT_030_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT030"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_030_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "BREAD",
                                        },
                                        YieldPercentage = 0.795,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 168
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_030"
                                }
                            }
                        },
                     },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_030"
        },
    }
})



-- Event: 031 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event031.png", "TEXTURE_TAS_EVENT031")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_031",
    Title = "EVENT_TAS_EVENT_031_TITLE",
	Description = "EVENT_TAS_EVENT_031_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_031_TITLE",
                Description = "EVENT_TAS_EVENT_031_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT031"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_031_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "FISH",
                                        },
                                        YieldPercentage = 0.795,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 84
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_031"
                                }
                            }
                        },
                     },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_031"
        },
    }
})



-- Event: 032 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event032.png", "TEXTURE_TAS_EVENT032")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_032",
    Title = "EVENT_TAS_EVENT_032_TITLE",
	Description = "EVENT_TAS_EVENT_032_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_032_TITLE",
                Description = "EVENT_TAS_EVENT_032_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT032"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_032_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_RESOURCES",
                                    ResourceCollection = {
                                        {
                                            Resource = "FISH",
                                            Quantity = 500
                                        },
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_032"
        },
    }
})



-- Event: 033 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event033.png", "TEXTURE_TAS_EVENT033")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_033",
    Title = "EVENT_TAS_EVENT_033_TITLE",
	Description = "EVENT_TAS_EVENT_033_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_033_TITLE",
                Description = "EVENT_TAS_EVENT_033_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT033"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_033_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_QUEST",
                            Quest = "QUEST_TAS_EVENT_033_RESPOND1"
                        },
                        {
                            DataType = "EVENT_ACTION_GIVE_QUEST",
                            Quest = "QUEST_TAS_EVENT_033_RESPOND2"
                        },
                        {
                            DataType = "EVENT_ACTION_GIVE_QUEST",
                            Quest = "QUEST_TAS_EVENT_033_RESPOND3"
                        },
                        {
                            DataType = "EVENT_ACTION_GIVE_QUEST",
                            Quest = "QUEST_TAS_EVENT_033_RESPOND4"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_033"
        },
    }
})

-- Quest ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_EVENT_033_RESPOND1",
    Name = "QUEST_TAS_EVENT_033_RESPOND_NAME",
    Description = "QUEST_TAS_EVENT_033_RESPOND_DESC",
    IsSilent = false,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_DELIVER_RESOURCES", 
        Estate = "LABOUR",
        ResourceListToDeliver = {
            { 
                Resource = "BREAD",
                Quantity = 100
            },
        },
        DaysCount = 56
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "WOOLEN_CLOTH",
                },
                YieldPercentage = 1.1,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 336
            },
            OptionalApplicator = "EVENT_TAS_EVENT_033"
        },
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})

-- Quest ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_EVENT_033_RESPOND2",
    Name = "QUEST_TAS_EVENT_033_RESPOND_NAME",
    Description = "QUEST_TAS_EVENT_033_RESPOND_DESC",
    IsSilent = false,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_DELIVER_RESOURCES", 
        Estate = "LABOUR",
        ResourceListToDeliver = {
            { 
                Resource = "CHEESE",
                Quantity = 100
            },
        },
        DaysCount = 56
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "WOOLEN_CLOTH",
                },
                YieldPercentage = 1.1,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 336
            },
            OptionalApplicator = "EVENT_TAS_EVENT_033"
        },
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})

-- Quest ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_EVENT_033_RESPOND3",
    Name = "QUEST_TAS_EVENT_033_RESPOND_NAME",
    Description = "QUEST_TAS_EVENT_033_RESPOND_DESC",
    IsSilent = false,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_DELIVER_RESOURCES", 
        Estate = "LABOUR",
        ResourceListToDeliver = {
            { 
                Resource = "BEER",
                Quantity = 50
            },
        },
        DaysCount = 56
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "WOOLEN_CLOTH",
                },
                YieldPercentage = 1.1,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 336
            },
            OptionalApplicator = "EVENT_TAS_EVENT_033"
        },
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})

-- Quest ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_EVENT_033_RESPOND4",
    Name = "QUEST_TAS_EVENT_033_RESPOND_NAME",
    Description = "QUEST_TAS_EVENT_033_RESPOND_DESC",
    IsSilent = false,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_DELIVER_RESOURCES", 
        Estate = "LABOUR",
        ResourceListToDeliver = {
            { 
                Resource = "WINE",
                Quantity = 50
            },
        },
        DaysCount = 56
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_GAME_RULE",
            RuleModifier = {
                DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                ResourceList = {
                    "WOOLEN_CLOTH",
                },
                YieldPercentage = 1.1,
                IsUntilRemoval = false, 
                IsGlobal = true, 
                DurationInDays = 336
            },
            OptionalApplicator = "EVENT_TAS_EVENT_033"
        },
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})



-- Event: 034 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event034.png", "TEXTURE_TAS_EVENT034")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_034",
    Title = "EVENT_TAS_EVENT_034_TITLE",
	Description = "EVENT_TAS_EVENT_034_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_034_TITLE",
                Description = "EVENT_TAS_EVENT_034_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT034"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_034_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "RESOURCE_FLAX",
                                        },
                                        YieldPercentage = 0.20,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_034"
                                }
                            }
                        },
                     },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_034"
        },
    }
})



-- Event: 035 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event035.png", "TEXTURE_TAS_EVENT035")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_035",
    Title = "EVENT_TAS_EVENT_035_TITLE",
	Description = "EVENT_TAS_EVENT_035_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_035_TITLE",
                Description = "EVENT_TAS_EVENT_035_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT035"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_035_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_RESOURCES",
                                    ResourceCollection = {
                                        {
                                            Resource = "IRON",
                                            Quantity = 200
                                        },
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_035"
        },
    }
})



-- Event: 036 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event036.png", "TEXTURE_TAS_EVENT036")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_036",
    Title = "EVENT_TAS_EVENT_036_TITLE",
	Description = "EVENT_TAS_EVENT_036_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_036_TITLE",
                Description = "EVENT_TAS_EVENT_036_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT036"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_036_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_RESOURCES",
                                    ResourceCollection = {
                                        {
                                            Resource = "BARREL",
                                            Quantity = 200
                                        },
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_036"
        },
    }
})



-- Event: 037 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event037.png", "TEXTURE_TAS_EVENT037")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_037",
    Title = "EVENT_TAS_EVENT_037_TITLE",
	Description = "EVENT_TAS_EVENT_037_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_037_TITLE",
                Description = "EVENT_TAS_EVENT_037_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT037"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_037_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "BOAR",
                                        },
                                        YieldPercentage = 0.595,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 112
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_037"
                                }
                            }
                        },
                     },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_037"
        },
    }
})



-- Event: 038 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event038.png", "TEXTURE_TAS_EVENT038")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_038",
    Title = "EVENT_TAS_EVENT_038_TITLE",
	Description = "EVENT_TAS_EVENT_038_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_038_TITLE",
                Description = "EVENT_TAS_EVENT_038_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT038"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_038_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_QUEST",
                            Quest = "QUEST_TAS_EVENT_038_RESPOND1"
                        },
                        {
                            DataType = "EVENT_ACTION_GIVE_QUEST",
                            Quest = "QUEST_TAS_EVENT_038_RESPOND2"
                        },
                        {
                            DataType = "EVENT_ACTION_GIVE_QUEST",
                            Quest = "QUEST_TAS_EVENT_038_RESPOND3"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_038"
        },
    }
})

-- Quest ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_EVENT_038_RESPOND1",
    Name = "QUEST_TAS_EVENT_038_RESPOND_NAME",
    Description = "QUEST_TAS_EVENT_038_RESPOND_DESC",
    IsSilent = false,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_DELIVER_RESOURCES", 
        Estate = "LABOUR",
        ResourceListToDeliver = {
            { 
                Resource = "BOAR",
                Quantity = 100
            },
        },
        DaysCount = 14
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_INFLUENCE",
            EstateInfluence = {
                Estate = "KINGDOM",
                Quantity = 10
            }
        },
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})

-- Quest ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_EVENT_038_RESPOND2",
    Name = "QUEST_TAS_EVENT_038_RESPOND_NAME",
    Description = "QUEST_TAS_EVENT_038_RESPOND_DESC",
    IsSilent = false,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_DELIVER_RESOURCES", 
        Estate = "LABOUR",
        ResourceListToDeliver = {
            { 
                Resource = "CHEESE",
                Quantity = 100
            },
        },
        DaysCount = 14
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_INFLUENCE",
            EstateInfluence = {
                Estate = "KINGDOM",
                Quantity = 10
            }
        },
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})

-- Quest ---------------------------------------------------------------------------------------------
mod:register({
    DataType = "QUEST",
    Id = "QUEST_TAS_EVENT_038_RESPOND3",
    Name = "QUEST_TAS_EVENT_038_RESPOND_NAME",
    Description = "QUEST_TAS_EVENT_038_RESPOND_DESC",
    IsSilent = false,
	QuestFunction = {
        DataType = "QUEST_FUNCTION_DELIVER_RESOURCES", 
        Estate = "LABOUR",
        ResourceListToDeliver = {
            { 
                Resource = "WINE",
                Quantity = 100
            },
        },
        DaysCount = 14
    },
    QuestRewardList = {
        {
            DataType = "QUEST_REWARD_INFLUENCE",
            EstateInfluence = {
                Estate = "KINGDOM",
                Quantity = 10
            }
        },
    },
    QuestFailList = nil,
    QuestListToUnlockAfter = nil,
    OnFailCallback = nil,
    OnSuccessCallback = nil
})



-- Event: 039 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event039.png", "TEXTURE_TAS_EVENT039")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_039",
    Title = "EVENT_TAS_EVENT_039_TITLE",
	Description = "EVENT_TAS_EVENT_039_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_039_TITLE",
                Description = "EVENT_TAS_EVENT_039_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT039"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_039_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_PAY",
                            AmountToPay = {
                                {
                                    Resource = "RESOURCE_THATCH",
                                    Quantity = 250
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_039"
        },
    }
})



-- Event: 040 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event040.png", "TEXTURE_TAS_EVENT040")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_040",
    Title = "EVENT_TAS_EVENT_040_TITLE",
	Description = "EVENT_TAS_EVENT_040_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_040_TITLE",
                Description = "EVENT_TAS_EVENT_040_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT040"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_040_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_PAY",
                            AmountToPay = {
                                {
                                    Resource = "WHEAT",
                                    Quantity = 200
                                },
                            }
                        },
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "WHEAT",
                                        },
                                        YieldPercentage = 0.75,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 56
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_040"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_040"
        },
    }
})



-- Event: 041 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event041.png", "TEXTURE_TAS_EVENT041")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_041",
    Title = "EVENT_TAS_EVENT_041_TITLE",
	Description = "EVENT_TAS_EVENT_041_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_041_TITLE",
                Description = "EVENT_TAS_EVENT_041_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT041"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_041_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_PAY",
                            AmountToPay = {
                                {
                                    Resource = "GOLD_COINS",
                                    Quantity = 250
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_041"
        },
    }
})



-- Event: 042 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event042.png", "TEXTURE_TAS_EVENT042")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_042",
    Title = "EVENT_TAS_EVENT_042_TITLE",
	Description = "EVENT_TAS_EVENT_042_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_042_TITLE",
                Description = "EVENT_TAS_EVENT_042_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT042"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_042_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_042"
        },
    }
})



-- Event: 043 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event043.png", "TEXTURE_TAS_EVENT043")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_043",
    Title = "EVENT_TAS_EVENT_043_TITLE",
	Description = "EVENT_TAS_EVENT_043_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_043_TITLE",
                Description = "EVENT_TAS_EVENT_043_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT043"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_043_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_GAME_RULE",
                                    RuleModifier = {
                                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                                        ResourceList = {
                                            "TOOL",
                                        },
                                        YieldPercentage = 0.795,
                                        IsUntilRemoval = false,
                                        IsGlobal = true,
                                        DurationInDays = 84
                                    },
                                    OptionalApplicator = "EVENT_TAS_EVENT_043"
                                }
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_043"
        },
    }
})



-- Event: 044 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event044.png", "TEXTURE_TAS_EVENT044")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_044",
    Title = "EVENT_TAS_EVENT_044_TITLE",
	Description = "EVENT_TAS_EVENT_044_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_044_TITLE",
                Description = "EVENT_TAS_EVENT_044_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT044"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_044_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_044"
        },
    }
})



-- Event: 045 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event045.png", "TEXTURE_TAS_EVENT045")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_045",
    Title = "EVENT_TAS_EVENT_045_TITLE",
	Description = "EVENT_TAS_EVENT_045_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_045_TITLE",
                Description = "EVENT_TAS_EVENT_045_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT045"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_045_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_045"
        },
    }
})



-- Event: 046 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event046.png", "TEXTURE_TAS_EVENT046")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_046",
    Title = "EVENT_TAS_EVENT_046_TITLE",
	Description = "EVENT_TAS_EVENT_046_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_046_TITLE",
                Description = "EVENT_TAS_EVENT_046_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT046"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_046_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_GIVE_REWARD",
                            QuestRewardList = {
                                {
                                    DataType = "QUEST_REWARD_RESOURCES",
                                    ResourceCollection = {
                                        {
                                            Resource = "GOLD_COINS",
                                            Quantity = 500
                                        },
                                    }
                                },
                            }
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_046"
        },
    }
})



-- Event: 047 ---------------------------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/Event047.png", "TEXTURE_TAS_EVENT047")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_TAS_EVENT_047",
    Title = "EVENT_TAS_EVENT_047_TITLE",
	Description = "EVENT_TAS_EVENT_047_DESC",
    IsInMainPool = false,
    IsRecurrent = true,
    DaysToFirst = 1,
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_TAS_EVENT_047_TITLE",
                Description = "EVENT_TAS_EVENT_047_DESC",
                PanelVisual = "TEXTURE_TAS_EVENT047"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_TAS_EVENT_047_CHOICE_1",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_QUEST",
            Quest = "QUEST_TAS_EVENT_047"
        },
    }
})
