local mod = ...



-- Default Balancing (event list) ---------------------------------------------------------------------------------------------

mod:override({
    Id = "DEFAULT_BALANCING",
    EventList = {
        Action = "APPEND",
        "EVENT_FESTIVAL_WINTER_SETUP",
    }
})



-- Event: Fast Setup ---------------------------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_FESTIVAL_WINTER_SETUP",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
    DaysToFirst = 1, -- 1st day of Month 11 (two week warning before fast starts on Month 11 Week 2 Day 1)
	ConditionList = {
	},
	ActionList = {
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
			OnClickCallback = {
				DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
				Event = "EVENT_FESTIVAL_WINTER_PRE",
				Delay = 266 * 60
			},
            QuestRewardList = {
            }
        },
    }
})



-- Event: Fast Pre-Notification ---------------------------------------------------------------------------------------------
mod:registerAssetId("models/Textures/WinterFast.png", "TEXTURE_FESTIVAL_WINTER")

mod:register({
	DataType = "EVENT",
    Id = "EVENT_FESTIVAL_WINTER_PRE",
    Title = "EVENT_FESTIVAL_WINTER_PRE_TITLE",
	Description = "EVENT_FESTIVAL_WINTER_PRE_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = false,
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_FESTIVAL_WINTER_PRE_TITLE",
                Description = "EVENT_FESTIVAL_WINTER_PRE_DESC",
                PanelVisual = "TEXTURE_FESTIVAL_WINTER"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_FESTIVAL_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            OnClickCallback = {
                DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
                Event = "EVENT_FESTIVAL_WINTER_START",
                Delay = 14 * 60
            },
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_CROP_YIELDS",
                        ResourceList = {
                            "RESOURCE_SECURITY",
                        },
                        YieldPercentage = 2.0,
                        IsUntilRemoval = false,
                        IsGlobal = true,
                        DurationInDays = 13
                    },
                    OptionalApplicator = "EVENT_FESTIVAL_WINTER_PRE"                
                },
            },
        },
    }
})



-- Villager Need : Entertainment (if it doesn't already exist) -------------------------------------------------------------------------------------
-- If Street performers is not loaded, this need will be created but not used for anything, just to avoid a crash on subsequent code

if (not foundation.isModLoaded("9475b42e-f880-4787-9b07-bec720fc90b6")) then -- Street Performers mod is not already loaded

    mod:register({
        DataType = "HAPPINESS_FACTOR",
        Id = "HAPPINESS_FACTOR_ENTERTAINMENT",
        Value = -2,
        IsDecaying = true,
        TimeBeforeDecayingSeconds = 120.0,
        DecayingRatePerMinute = 3.5, -- default is 2.0
        IsCumulative = true,
        IsSolvable = true,
        RemovedOnDecayed = false
    })

    mod:register({
        DataType = "VILLAGER_NEED_TYPE",
        Id = "NEED_ENTERTAINMENT",
        NeedTypeName = "NEED_ENTERTAINMENT_NAME",
        NeedTypeList = {"ENTERTAINMENT"}, -- this need type already exists in the vanilla game
        FillDurationInSeconds = 1680, -- 420 seems to be the duration of water and food, 2-3 days
        FillRate = 100,
        GracePeriod = 7,
        HappinessFactor = "HAPPINESS_FACTOR_ENTERTAINMENT",
        ResourceTypeIcon = "ICON_ENTERTAINMENT"
    })
end



-- Villager Need : Security (if it doesn't already exist) -------------------------------------------------------------------------------------
-- If Security is not loaded, this need will be created but not used for anything, just to avoid a crash on subsequent code
-- I found that reducing the depletion rate was insufficient because Security is not often consumed, so many people were needing it during the Fast

if (not foundation.isModLoaded("99ee3b3b-f103-41f0-a725-bc466a2fc6de")) then -- Street Performers mod is not already loaded

    mod:register({
        DataType = "HAPPINESS_FACTOR",
        Id = "HAPPINESS_FACTOR_SECURITY",
        Value = -2,
        IsDecaying = true,
        TimeBeforeDecayingSeconds = 120.0,
        DecayingRatePerMinute = 3.5,
        IsCumulative = true,
        IsSolvable = true,
        RemovedOnDecayed = false
    })

    mod:register({
        DataType = "VILLAGER_NEED_TYPE",
        Id = "NEED_SECURITY",
        NeedTypeName = "NEED_SECURITY_NAME",
        NeedTypeList = {"RESOURCE_TYPE_SECURITY"},
        FillDurationInSeconds = 1000, -- increased from 600 to 1000 seconds for v1.0.3; this is now the same rhythm as for Fuel
        FillRate = 100,
        GracePeriod = 7,
        HappinessFactor = "HAPPINESS_FACTOR_SECURITY",
        ResourceTypeIcon = "ICON_SECURITY"
    })

end



-- Event: Winter Fast Start ----------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_FESTIVAL_WINTER_START",
    Title = "EVENT_FESTIVAL_WINTER_START_TITLE",
	Description = "EVENT_FESTIVAL_WINTER_START_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = true,
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_FESTIVAL_WINTER_START_TITLE",
                Description = "EVENT_FESTIVAL_WINTER_START_DESC",
                PanelVisual = "TEXTURE_FESTIVAL_WINTER"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_FESTIVAL_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            OnClickCallback = {
                DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
                Event = "EVENT_FESTIVAL_WINTER_END",
                Delay = 28 * 60
            },
            QuestRewardList = {
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_NEED_TYPE_DEPLETE_RATE",
                        NeedType = "NEED_PRIMARY_NEED",
                        BonusInPerc = 4.5,
                        IsUntilRemoval = false,
                        IsGlobal = true,
                        DurationInDays = 27
                    },
                    OptionalApplicator = "EVENT_FESTIVAL_WINTER_START"
                },
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_NEED_TYPE_DEPLETE_RATE",
                        NeedType = "NEED_FOOD",
                        BonusInPerc = 4.5,
                        IsUntilRemoval = false,
                        IsGlobal = true,
                        DurationInDays = 27
                    },
                    OptionalApplicator = "EVENT_FESTIVAL_WINTER_START"
                },
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_NEED_TYPE_DEPLETE_RATE",
                        NeedType = "NEED_GOODS",
                        BonusInPerc = 4.5,
                        IsUntilRemoval = false,
                        IsGlobal = true,
                        DurationInDays = 27
                    },
                    OptionalApplicator = "EVENT_FESTIVAL_WINTER_START"
                },
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_NEED_TYPE_DEPLETE_RATE",
                        NeedType = "NEED_LUXURY",
                        BonusInPerc = 4.5,
                        IsUntilRemoval = false,
                        IsGlobal = true,
                        DurationInDays = 27
                    },
                    OptionalApplicator = "EVENT_FESTIVAL_WINTER_START"
                },
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_NEED_TYPE_DEPLETE_RATE",
                        NeedType = "NEED_ENTERTAINMENT",
                        BonusInPerc = 4.5,
                        IsUntilRemoval = false,
                        IsGlobal = true,
                        DurationInDays = 27
                    },
                    OptionalApplicator = "EVENT_FESTIVAL_WINTER_START"
                },
                {
                    DataType = "QUEST_REWARD_GAME_RULE",
                    RuleModifier = {
                        DataType = "GAME_RULE_MODIFIER_NEED_TYPE_DEPLETE_RATE",
                        NeedType = "NEED_SECURITY",
                        BonusInPerc = 4.5,
                        IsUntilRemoval = false,
                        IsGlobal = true,
                        DurationInDays = 27
                    },
                    OptionalApplicator = "EVENT_FESTIVAL_WINTER_START"
                },
            }
        },    
    }
})



-- Event: Winter Fast End ----------------------------------------------------------------------------
mod:register({
	DataType = "EVENT",
    Id = "EVENT_FESTIVAL_WINTER_END",
    Title = "EVENT_FESTIVAL_WINTER_END_TITLE",
	Description = "EVENT_FESTIVAL_WINTER_END_DESC",
    IsInMainPool = false, -- the main pool seems to suppress itself until the first Weather event fires, so custom events should be outside the main pool
    IsRecurrent = true,
    DaysToFirst = 1, --309, -- 1st day of Month 11 Week 2 Day 1
    Delay = 30, -- seconds after the start of the day
	ConditionList = nil,
	ActionList = {
        {
            DataType = "ACTION_SHOW_NARRATIVE_PANEL",
            NarrativePanelData = {
                DataType = "DATA_NARRATIVE_PANEL",
                Title = "EVENT_FESTIVAL_WINTER_END_TITLE",
                Description = "EVENT_FESTIVAL_WINTER_END_DESC",
                PanelVisual = "TEXTURE_FESTIVAL_WINTER"
            },
            ChoiceList = {
                {
                    DataType = "EVENT_CHOICE",
                    ShortName = "EVENT_FESTIVAL_OK",
                    EventActionList = {
                        {
                            DataType = "EVENT_ACTION_IGNORE"
                        },
                    },
                    OnClickCallbackList = nil
                },
            },
            OnClickCallback = nil
        },
        {
            DataType = "EVENT_ACTION_GIVE_REWARD",
            OnClickCallback = {
                DataType = "EVENT_CALLBACK_TRIGGER_EVENT",
                Event = "EVENT_FESTIVAL_WINTER_PRE",
                Delay = (28 + 266) * 60
            },
            QuestRewardList = {
            }
        },
}
})



-- Custom Component: for each Workplace -------------------------------------------------------------------------------------
local COMP_TAS_FAST_WORKPLACE = {
	TypeName = "COMP_TAS_FAST_WORKPLACE",
	ParentType = "COMPONENT",
	Properties = {
        { Name = "IsPausedBeforeFast", Type = "boolean", Default = nil, Flags = { "SAVE_GAME" } },
    }
}



-- Register custom Class
mod:registerClass(COMP_TAS_FAST_WORKPLACE)



-- Function: Mid-Winter fast active (triggered from time.lua) ----------------------------------------------------------------------------
function tas_event_fast_active(comp)

    -- Loop through all workplaces and pause
    comp:getLevel():getComponentManager("COMP_WORKPLACE"):getAllComponent():forEach(function(compworkplace)

        compworkplace:getOwner():getOrCreateComponent("COMP_TAS_FAST_WORKPLACE")

        -- mod:log("Workplace component: " .. tostring(compworkplace:getOwner().Name))        
        -- mod:log(tostring(compworkplace:getOwner():getComponent("COMP_TAS_FAST_WORKPLACE").IsPausedBeforeFast))
        
        -- Record whether the workplace is paused or not, before the fast ban is applied
        if (comp.WeekCurrent == 1 and comp.DayCurrent == 1) then
            -- mod:log("Its the first day of the fast.")
            -- mod:log("Workplace pause state: " .. tostring(compworkplace.IsPaused))
            if (compworkplace.IsPaused) then -- the workplace is currently paused
                compworkplace:getOwner():getComponent("COMP_TAS_FAST_WORKPLACE").IsPausedBeforeFast = true
            else -- the workplace is currently active
                compworkplace:getOwner():getComponent("COMP_TAS_FAST_WORKPLACE").IsPausedBeforeFast = false
            end
        end

        -- Turn off all workplaces except for those fulfilling needs
        local namecheck1 = string.find(string.upper(tostring(compworkplace:getOwner().Name)), "MARKET") -- Market tables
        local namecheck2 = string.find(string.upper(tostring(compworkplace:getOwner().Name)), "CART") -- Market and Fuel carts
        local namecheck3 = string.find(string.upper(tostring(compworkplace:getOwner().Name)), "CHURCH") -- all types of Churches
        local namecheck4 = string.find(string.upper(tostring(compworkplace:getOwner().Name)), "PLATFORMPART") -- Town Crier
        if (not namecheck1 and not namecheck2 and not namecheck3 and not namecheck4) then
            compworkplace.IsPaused = true
        end

        -- mod:log(tostring(compworkplace:getOwner():getComponent("COMP_TAS_FAST_WORKPLACE").IsPausedBeforeFast))

    end)

end



-- Function: Mid-Winter fast ends (triggered from time.lua) ----------------------------------------------------------------------------
function tas_event_fast_end(comp)

    -- Loop through all workplaces and unpause, if they were not paused before the fast
    comp:getLevel():getComponentManager("COMP_WORKPLACE"):getAllComponent():forEach(function(compworkplace)

        -- mod:log("Workplace component: " .. tostring(compworkplace:getOwner().Name))        
        compworkplace:getOwner():getOrCreateComponent("COMP_TAS_FAST_WORKPLACE")

        if (compworkplace:getOwner():getComponent("COMP_TAS_FAST_WORKPLACE").IsPausedBeforeFast == false) then -- this workplace was active before the fast
            compworkplace.IsPaused = false -- unpause
        end

    end)

end
 




