local mod = ...



-- Custom Component: Calendar -------------------------------------------------------------------------------------
local COMP_TAS_CALENDAR = {
	TypeName = "COMP_TAS_CALENDAR",
	ParentType = "COMPONENT",
	Properties = {
		{
            Name = "SeasonCurrent",
            Type = "string",
            Default = "Spring",
            Flags = { "SAVE_GAME" }
        },
		{
            Name = "YearCurrent",
            Type = "integer",
            Default = 1,
            Flags = { "SAVE_GAME" }
        },
		{
            Name = "MonthCurrent",
            Type = "integer",
            Default = 1,
            Flags = { "SAVE_GAME" } 
        },
		{
            Name = "WeekCurrent",
            Type = "integer",
            Default = 1, 
            Flags = { "SAVE_GAME" } 
        },
		{
            Name = "DayCurrent",
            Type = "integer",
            Default = 0, 
            Flags = { "SAVE_GAME" } 
        },
		{
            Name = "DaysFromStart",
            Type = "integer",
            Default = 0, 
            Flags = { "SAVE_GAME" } 
        },
    }
}



-- Put listeners on new days
-- When a new period begins, increment to the next day, week, or month as appropriate
-- Remember the current season

function COMP_TAS_CALENDAR:init()

    mod:log("COMP_TAS_CALENDAR ______________________________________________________________________________________")

    local compMainGameLoop = self:getLevel():find("COMP_MAIN_GAME_LOOP")

    event.register(self, compMainGameLoop.ON_NEW_DAY, function()

        -- mod:log("Times and Seasons: New Day function started")

        self.DaysFromStart = self.DaysFromStart + 1

        if (self.DayCurrent == 7) then -- new week
            self.DayCurrent = 1

            if (self.WeekCurrent == 4) then -- new month
                self.WeekCurrent = 1

                if (self.MonthCurrent == 12) then -- new year
                    self.MonthCurrent = 1
                    self.YearCurrent = tonumber(self.YearCurrent) + 1
                else
                    self.MonthCurrent = tonumber(self.MonthCurrent) + 1
                end

                if (self.MonthCurrent == 1) then
                    self.SeasonCurrent = "Spring"                    
                elseif (self.MonthCurrent == 4) then
                    self.SeasonCurrent = "Summer"
                elseif (self.MonthCurrent == 7) then
                    self.SeasonCurrent = "Autumn" 
                elseif (self.MonthCurrent == 10) then
                    self.SeasonCurrent = "Winter"
                end

            else -- same month
                self.WeekCurrent = tonumber(self.WeekCurrent) + 1
            end

        else -- same week
            self.DayCurrent = tonumber(self.DayCurrent) + 1
        end

        mod:log("CURRENT TIME: SEASON " .. tostring(self.SeasonCurrent) .. "   YEAR " .. tostring(self.YearCurrent) .. "   MONTH " .. tostring(self.MonthCurrent) .. "   WEEK " .. tostring(self.WeekCurrent) .. "   DAY " .. tostring(self.DayCurrent) .. "   DAYS FROM START " .. tostring(self.DaysFromStart) .. "    ++++++++++++++++++++++++++++++++++++++")


        -- Weather ---------------------------------------------------------------------------------------------------------------------------------
        local compWeather = self:getLevel():find("COMP_TAS_WEATHER")

        -- Reduce the time remaining on the current weather system
        compWeather.CurrentSystemDaysRemaining = compWeather.CurrentSystemDaysRemaining - 1
        -- mod:log("Weather Days remaining: " .. compWeather.CurrentSystemDaysRemaining)
        -- mod:log("Weather record:")
        -- for i, p in ipairs(compWeather.DailyWeatherRecord) do
        --     mod:log(tostring(p))
        -- end

        -- remove the fourteenth day in the current weather record
        table.remove(compWeather.DailyWeatherRecord)

        -- If the weather system is finished, randomly choose a new one
        if (compWeather.CurrentSystemDaysRemaining <= 1) then

            compWeather.CurrentSystemDaysRemaining = math.random(2, 8) -- new weather system of duration between x and y days

            local randtempfact = math.random()
            local randtemp = 1 -- normal by default
            if (self.SeasonCurrent == "Spring" or self.SeasonCurrent == "Autumn") then
                if randtempfact <= 0.20 then 
                    randtemp = 0 -- cool
                elseif randtempfact >= 0.80 then
                    randtemp = 2 -- warm
                end
            elseif (self.SeasonCurrent == "Summer") then
                if randtempfact <= 0.20 then 
                    randtemp = 0 -- cool
                elseif randtempfact >= 0.80 then
                    randtemp = 2 -- warm
                end
            elseif (self.SeasonCurrent == "Winter") then
                if randtempfact <= 0.20 then 
                    randtemp = 0 -- cool
                elseif randtempfact >= 0.80 then
                    randtemp = 2 -- warm
                end
            end

            local randprecfact = math.random()
            local randprec = 0 -- dry by default
            if (self.SeasonCurrent == "Spring" or self.SeasonCurrent == "Autumn") then
                if randprecfact <= 0.35 then 
                    randprec = 2 -- wet 
                else
                    randprec = 0 -- dry
                end
            elseif (self.SeasonCurrent == "Summer") then
                if randprecfact <= 0.25 then
                    randprec = 2 -- wet 
                else
                    randprec = 0 -- dry
                end
            elseif (self.SeasonCurrent == "Winter") then
                if randprecfact <= 0.45 then 
                    randprec = 2 -- wet 
                else
                    randprec = 0 -- dry
                end
            end

            -- insert the new weather into the first value of the table
            table.insert(compWeather.DailyWeatherRecord, 1, {randtemp, randprec})

        -- If the weather system duration is not completed, copy the last value to today (same weather today as yesterday)
        else
            
            table.insert(compWeather.DailyWeatherRecord, 1, { compWeather.DailyWeatherRecord[1][1], compWeather.DailyWeatherRecord[1][2] })

        end

        -- mod:log("Current weather: Temp " .. compWeather.DailyWeatherRecord[1][1] .. ", Precipitation " .. compWeather.DailyWeatherRecord[1][2])

        -- Count the number of wet and dry days in the last 14 days
        local countwetdays = 0
        for i, p in ipairs(compWeather.DailyWeatherRecord) do
            if p[2] == 2 then -- wet
                countwetdays = countwetdays + 1
            end
        end

        -- Find the first villager you can use to trigger the event/quest
        local compVillager = self:getLevel():find("COMP_VILLAGER", true)
        local compJob = compVillager:getAssetJob()
        local compJobInstance = compVillager:getJobInstance()
        if (compJobInstance) then
            local compJobWorkplace = compJobInstance.Workplace
        else
            local compJobWorkplace = ""
        end        

        -- Trigger each weather type's quest/event to implement game rule modifications, by momentarily assigning the appropriate trigger job
        -- mod:log("Weather record:")
        -- for i, p in ipairs(compWeather.DailyWeatherRecord) do
        --     mod:log(tostring(p))
        -- end

        -- mod:log("Wet days in the last fourteen: " .. countwetdays)


        -- Winter production effects
        if (self.SeasonCurrent == "Winter") then

            -- Too cool (crops and livestock)
            if (compWeather.DailyWeatherRecord[1][1] == 0) then
                compVillager:changeJob("JOB_TAS_WEATHER_CROP_DECREASE")
                compVillager:changeJob("JOB_TAS_WEATHER_LIVESTOCK_DECREASE")
                compVillager:changeJob(compJob, compJobWorkplace)
            end

            -- Too wet (crops)
            if (countwetdays >= 14) then
                compVillager:changeJob("JOB_TAS_WEATHER_CROP_DECREASE")
                compVillager:changeJob(compJob, compJobWorkplace)
            end

            -- Warm and perfect amount of rain (crops)
            if (compWeather.DailyWeatherRecord[1][1] == 2 and countwetdays >= 2 and countwetdays <= 10) then
                compVillager:changeJob("JOB_TAS_WEATHER_CROP_INCREASE")
                compVillager:changeJob(compJob, compJobWorkplace)
            end

            -- Warm (livestock)
            if (compWeather.DailyWeatherRecord[1][1] == 2) then
                compVillager:changeJob("JOB_TAS_WEATHER_LIVESTOCK_INCREASE")
                compVillager:changeJob(compJob, compJobWorkplace)
            end

        -- Spring, Summer and Autumn production effects
        else 

            -- Too cool (crops and livestock)
            if (compWeather.DailyWeatherRecord[1][1] == 0) then
                compVillager:changeJob("JOB_TAS_WEATHER_CROP_DECREASE")
                compVillager:changeJob("JOB_TAS_WEATHER_LIVESTOCK_DECREASE")
                compVillager:changeJob(compJob, compJobWorkplace)
            end

            -- Too wet or too dry (crops)
            if (countwetdays >= 14 or countwetdays == 0) then
                compVillager:changeJob("JOB_TAS_WEATHER_CROP_DECREASE")
                compVillager:changeJob(compJob, compJobWorkplace)
            end

            -- Warm and perfect amount of rain (crops)
            if (compWeather.DailyWeatherRecord[1][1] == 2 and countwetdays >= 2 and countwetdays <= 10) then
                compVillager:changeJob("JOB_TAS_WEATHER_CROP_INCREASE")
                compVillager:changeJob(compJob, compJobWorkplace)
            end

            -- Too warm in summer (livestock)
            if (self.SeasonCurrent == "Summer" and compWeather.DailyWeatherRecord[1][1] == 2) then
                compVillager:changeJob("JOB_TAS_WEATHER_LIVESTOCK_DECREASE")
                compVillager:changeJob(compJob, compJobWorkplace)
            end

            -- Too dry (livestock)
            if (countwetdays == 0) then
                compVillager:changeJob("JOB_TAS_WEATHER_LIVESTOCK_DECREASE")
                compVillager:changeJob(compJob, compJobWorkplace)
            end

            -- Wet (livestock - better pastures)
            if (countwetdays >= 10) then
                compVillager:changeJob("JOB_TAS_WEATHER_LIVESTOCK_INCREASE")
                compVillager:changeJob(compJob, compJobWorkplace)
            end

        end
        
        -- Weather visual effects
        if (compWeather.DailyWeatherRecord[1][2] == 2) then
            compVillager:changeJob("JOB_TAS_WEATHER_RAIN")
            compVillager:changeJob(compJob, compJobWorkplace)
        else
            compVillager:changeJob("JOB_TAS_WEATHER_SUN")
            compVillager:changeJob(compJob, compJobWorkplace)
        end

        -- Temperature (for player information)
        if (self.SeasonCurrent == "Spring" or self.SeasonCurrent == "Autumn") then
            if (compWeather.DailyWeatherRecord[1][1] == 0) then
                compVillager:changeJob("JOB_TAS_WEATHER_TEMP10")
                compVillager:changeJob(compJob, compJobWorkplace)
            elseif (compWeather.DailyWeatherRecord[1][1] == 1) then
                compVillager:changeJob("JOB_TAS_WEATHER_TEMP15")
                compVillager:changeJob(compJob, compJobWorkplace)
            else
                compVillager:changeJob("JOB_TAS_WEATHER_TEMP20")
                compVillager:changeJob(compJob, compJobWorkplace)
            end
        elseif (self.SeasonCurrent == "Summer") then
            if (compWeather.DailyWeatherRecord[1][1] == 0) then
                compVillager:changeJob("JOB_TAS_WEATHER_TEMP15")
                compVillager:changeJob(compJob, compJobWorkplace)
            elseif (compWeather.DailyWeatherRecord[1][1] == 1) then
                compVillager:changeJob("JOB_TAS_WEATHER_TEMP20")
                compVillager:changeJob(compJob, compJobWorkplace)
            else
                compVillager:changeJob("JOB_TAS_WEATHER_TEMP25")
                compVillager:changeJob(compJob, compJobWorkplace)
            end
        elseif (self.SeasonCurrent == "Winter") then
            if (compWeather.DailyWeatherRecord[1][1] == 0) then
                compVillager:changeJob("JOB_TAS_WEATHER_TEMP1")
                compVillager:changeJob(compJob, compJobWorkplace)
            elseif (compWeather.DailyWeatherRecord[1][1] == 1) then
                compVillager:changeJob("JOB_TAS_WEATHER_TEMP5")
                compVillager:changeJob(compJob, compJobWorkplace)
            else
                compVillager:changeJob("JOB_TAS_WEATHER_TEMP10")
                compVillager:changeJob(compJob, compJobWorkplace)
            end
        end

        -- End weather ------------------------------------------------------------------------------------------------------------------------------



        -- Mid-Winter Fast --------------------------------------------------------------------------------------------------------------------------
        if (self.MonthCurrent == 11) then tas_event_fast_active(self) end -- run it every day of the fast, to ensure all workplaces are paused
        if (self.MonthCurrent == 12 and self.WeekCurrent == 1 and self.DayCurrent == 1) then tas_event_fast_end(self) end



        -- Events ------------------------------------------------------------------------------------------------------------------------------

        -- -- Dump building names for debugging
        -- self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
        --     mod:log("Building name: " .. tostring(compBuilding.AssetBuilding.Name))  
        -- end)

        -- Get event component
        compEvent = self:getLevel():find("COMP_TAS_EVENT")
        if (compEvent) then

            -- mod:log("Day of last event: " .. compEvent.DayLastEvent)

            -- Run event only if no event was run in the last 28 days
            if (compEvent.DayLastEvent < (self.DaysFromStart - 28)) then
            -- if (compEvent.DayLastEvent <= (self.DaysFromStart - 1)) then -- FOR TESTING

                -- Decide whether to run an event
                local xChoose = math.random()
                if (xChoose <= (1 / 28)) then -- chance of any event being considered
                -- if (xChoose <= (1 / 1)) then -- FOR TESTING

                    -- Randomly choose an event from the list
                    local xEvent = math.random(1, 47) -- randomly choose event between 1 and maximum number
                    local tEvent = string.sub("000" .. xEvent, -3)

                    -- mod:log("Event chosen: " .. xEvent)

                    -- Only run this event if it has not occurred in the last two years
                    if ((compEvent.EventTracker[xEvent][2] <= (self.DaysFromStart - 672)) or (compEvent.EventTracker[xEvent][2] == 0)) then
                    -- if ((compEvent.EventTracker[xEvent][2] <= (self.DaysFromStart - 1)) or (compEvent.EventTracker[xEvent][2] == 0)) then -- FOR TESTING

                        -- Only run this event if its specific conditions are met
                        local bCondition = false

                        -- Count villagers for use in some of the scenarios
                        local iVillager = #self:getLevel():getComponentManager("COMP_VILLAGER"):getAllEnabledComponent()

                        -- Troublesome Birds (lower yield of Berries)
                        if (xEvent == 1 and self.MonthCurrent <= 9) then bCondition = true end

                        -- Orchards Infested (lower yield of Apples)
                        if (xEvent == 2 and self.MonthCurrent <= 9) then 
                            -- Check that at least one Orchard is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "BUILDING_ORCHARD_NAME") then bCondition = true end
                            end)
                        end

                        -- Weavils (destroy all wheat and flour)
                        if (xEvent == 3) then 
                            -- Check that at least one Wheat Farm is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "WHEAT_FARM") then bCondition = true end
                            end)
                        end

                        -- New Fashions (destroy all clothes and furniture)
                        if (xEvent == 4) then 
                            -- Check that at least one Tailor is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "TAILORS_WORKSHOP") then bCondition = true end
                            end)
                        end

                        -- Guano (higher yield of Vegetables)
                        if (xEvent == 5 and self.MonthCurrent <= 9) then 
                            -- Check that at least one Vegetable Farm is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "VEGETABLEFARM_NAME") then bCondition = true end
                            end)
                        end

                        -- Blackfly (lower yield of Vegetables)
                        if (xEvent == 6 and self.MonthCurrent <= 9) then 
                            -- Check that at least one Vegetable Farm is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "VEGETABLEFARM_NAME") then bCondition = true end
                            end)
                        end

                        -- Flooding (lower yield of Fish)
                        if (xEvent == 7) then 
                            -- Check that at least one Fishing Hut is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "FISHERS_HUT") then bCondition = true end
                            end)
                        end

                        -- Foxes (lower yield of Poultry and Eggs)
                        if (xEvent == 8) then 
                            -- Check that at least one Fishing Hut is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "BUILDING_POULTRY_NAME") then bCondition = true end
                            end)
                        end

                        -- Sour Milk (lower yield of Milk)
                        if (xEvent == 9) then 
                            -- Check that at least one Dairy farm or Livestock Farm is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "DAIRY_FARM" or tostring(compBuilding.AssetBuilding.Name) == "LIVESTOCKFARM_NAME") then bCondition = true end
                            end)
                        end

                        -- Blown Away (lower yield of Wool)
                        if (xEvent == 10) then 
                            -- Check that at least one Sheep Farm or Livestock farm is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "SHEEP_FARM" or tostring(compBuilding.AssetBuilding.Name) == "LIVESTOCKFARM_NAME") then bCondition = true end
                            end)
                        end

                        -- Murrain (lower yield of all livestock)
                        if (xEvent == 11) then 
                            -- Check that at least one Dairy Farn, Sheep Farm, or Livestock farm is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "SHEEP_FARM" or tostring(compBuilding.AssetBuilding.Name) == "LIVESTOCKFARM_NAME" or tostring(compBuilding.AssetBuilding.Name) == "DAIRY_FARM") then bCondition = true end
                            end)
                        end

                        -- Priest Defrocked (slower Faith depletion)
                        if (xEvent == 12) then 
                            -- Check that at least one Church is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (string.find(string.upper(tostring(compBuilding.AssetBuilding.Name)), "CHURCH")) then bCondition = true end
                            end)
                        end

                        -- Stern Sermon (slower Luxury depletion)
                        if (xEvent == 13) then 
                            -- Check that at least one Church is built, and the population is over 200
                            local bFound = false
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (string.find(string.upper(tostring(compBuilding.AssetBuilding.Name)), "CHURCH")) then bFound = true end
                            end)
                            if (bFound) then
                                if (iVillager > 200) then bCondition = true end
                            end
                        end

                        -- Mauraders (pay gold)
                        if (xEvent == 14) then 
                            -- Check ratio of Soldiers and Guards, to the total population
                            iSoldier = 0
                            self:getLevel():getComponentManager("COMP_VILLAGER"):getAllEnabledComponent():forEach(function(compVillager)
                                _jobcheck = tostring(compVillager:getAssetJob())
                                if (string.find(string.upper(_jobcheck), "SOLDIER") or string.find(string.upper(_jobcheck), "GUARD")) then 
                                    iSoldier = iSoldier + 1
                                end
                            end)
                            if (iSoldier < (0.05 * iVillager)) then
                                bCondition = true
                            end
                            -- mod:log("Soldier and guard count: " .. iSoldier)
                        end

                        -- Buried Treasure (receive gold)
                        if (xEvent == 15) then bCondition = true end

                        -- Shipwreck (receive gold and immigrants)
                        if (xEvent == 16 and iVillager > 20) then 
                            -- Check that at least one Fishing Hut is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "FISHERS_HUT") then bCondition = true end
                            end)
                        end
                        
                        -- Smugglers Caught (receive weapons, treasure)
                        if (xEvent == 17) then bCondition = true end

                        -- Thieves Caught (receive gems or gold bounty)
                        if (xEvent == 18) then bCondition = true end

                        -- Guild Revolt (appease or face trouble)
                        if (xEvent == 19 and iVillager > 300) then bCondition = true end

                        -- Farmer Revolt (appease or face trouble)
                        if (xEvent == 20 and iVillager > 200) then bCondition = true end

                        -- Land Grant
                        if (xEvent == 21 and iVillager > 50) then bCondition = true end

                        -- Refugees
                        if (xEvent == 22 and iVillager > 30) then bCondition = true end

                        -- Famine
                        if (xEvent == 23 and iVillager > 100) then 
                            -- Check that at least one Fishing Hut is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "WHEAT_FARM") then bCondition = true end
                            end)
                        end

                        -- New Breeds
                        if (xEvent == 24) then 
                            -- Check that at least one Dairy Farn, Sheep Farm, Livestock farm, or poultry farm is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "SHEEP_FARM" or tostring(compBuilding.AssetBuilding.Name) == "LIVESTOCKFARM_NAME" or tostring(compBuilding.AssetBuilding.Name) == "DAIRY_FARM" or tostring(compBuilding.AssetBuilding.Name) == "BUILDING_POULTRY_NAME") then bCondition = true end
                            end)
                        end

                        -- Murder
                        if (xEvent == 25 and iVillager > 50) then 
                            xVillager = math.random(1, iVillager)
                            cVillager = 0
                            self:getLevel():getComponentManager("COMP_VILLAGER"):getAllEnabledComponent():forEach(function(compVillager)
                                cVillager = cVillager + 1
                                if (cVillager == xVillager) then -- delete them
                                    compVillager:getOwner():destroyAllChild()
                                    compVillager:getOwner():destroy()
                                end
                            end)
                            bCondition = true 
                        end

                        -- Water weed
                        if (xEvent == 26) then 
                            -- Check that at least one Fishing Hut is built, and at least one wheat or vegetable farm
                            local bFound = false
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (string.find(string.upper(tostring(compBuilding.AssetBuilding.Name)), "FISHERS_HUT")) then bFound = true end
                            end)
                            if (bFound) then
                                self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                    if (tostring(compBuilding.AssetBuilding.Name) == "WHEAT_FARM" or tostring(compBuilding.AssetBuilding.Name) == "VEGETABLEFARM_NAME") then bCondition = true end
                                end)
                            end
                        end

                        -- Travelling Blacksmith
                        if (xEvent == 27) then 
                            -- Check that at least one wheat farm is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "WHEAT_FARM") then bCondition = true end
                            end)
                        end


                        -- Expert Cheesemakers
                        if (xEvent == 28) then 
                            -- Check that no cheesemaker is built
                            bFound = false
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "CHEESE_MAKER") then bFound = true end
                            end)
                            if (not bFound) then bCondition = true end
                        end

                        -- Skilled Woodworkers
                        if (xEvent == 29) then 
                            -- Check that at least one wheat farm is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "WHEAT_FARM") then bCondition = true end
                            end)
                        end

                        -- Unhappy Bakers
                        if (xEvent == 30) then 
                            -- Check that at least one bakery is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "BAKERY") then bCondition = true end
                            end)
                        end

                        -- Drowning
                        if (xEvent == 31) then 
                            -- Check that fisher hut is built
                            bFound = false
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "FISHERS_HUT") then bFound = true end
                            end)
                            xVillager = 0
                            if (bFound) then
                                self:getLevel():getComponentManager("COMP_VILLAGER"):getAllEnabledComponent():forEach(function(compVillager)
                                    local compJob = compVillager:getAssetJob()
                                    if (compJob and xVillager == 0) then
                                        if (tostring(compJob.JobName) == "FISHERMAN") then
                                            compVillager:getOwner():destroyAllChild()
                                            compVillager:getOwner():destroy()
                                            xVillager = 1
                                        end
                                    end
                                end)
                                bCondition = true 
                            end
                        end

                        -- Massive Shoal
                        if (xEvent == 32) then 
                            -- Check that at least one fisher hut is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "FISHERS_HUT") then bCondition = true end
                            end)
                        end

                        -- Guild of Weavers
                        if (xEvent == 33) then 
                            -- Check that at least one weaver hut is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "WEAVER_HUT") then bCondition = true end
                            end)
                        end

                        -- Bad Flax
                        if (xEvent == 34) then 
                            local bFound = false
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (string.find(string.upper(tostring(compBuilding.AssetBuilding.Name)), "BUILDING_FLAXFARM_NAME")) then bFound = true end
                            end)
                            if (bFound) then
                                self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                    if (tostring(compBuilding.AssetBuilding.Name) == "TAILORS_WORKSHOP") then bCondition = true end
                                end)
                            end
                        end

                        -- Ancient Battle
                        if (xEvent == 35) then 
                            -- Check that at least one crop farm is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "WHEAT_FARM" or tostring(compBuilding.AssetBuilding.Name) == "BUILDING_FLAXFARM_NAME" or tostring(compBuilding.AssetBuilding.Name) == "VEGETABLEFARM_NAME") then bCondition = true end
                            end)
                        end

                        -- Barrels Afloat
                        if (xEvent == 36) then 
                            -- Check that at least one fisher hut is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "FISHERS_HUT") then bCondition = true end
                            end)
                        end

                        -- Poachers
                        if (xEvent == 37) then 
                            -- Check that at least one fisher hut is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "HUNTERS_HUT") then bCondition = true end
                            end)
                        end

                        -- Great Feast
                        if (xEvent == 38) then 
                            -- Check that at least one hunter or cheese maker is built
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "HUNTERS_HUT" or tostring(compBuilding.AssetBuilding.Name) == "CHEESE_MAKER") then bCondition = true end
                            end)
                        end

                        -- Damaged Thatch
                        if (xEvent == 39) then 
                            -- Check that at least one thatcher's yard
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "BUILDING_BASIC_THATCHER_NAME" and countwetdays >= 6) then bCondition = true end
                            end)
                        end

                        -- Rats
                        if (xEvent == 40) then 
                            -- Check that at least one wheat farm
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "WHEAT_FARM") then bCondition = true end
                            end)
                        end

                        -- Bad Well
                        if (xEvent == 41 and iVillager > 100) then 

                            -- Check that at least one well
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "WELL") then 

                                    -- kill 5 villagers
                                    for i=1, 5, 1 do
                                        cVillager = 0
                                        iVillager = #self:getLevel():getComponentManager("COMP_VILLAGER"):getAllEnabledComponent()
                                        xVillager = math.random(1, iVillager)
                                        self:getLevel():getComponentManager("COMP_VILLAGER"):getAllEnabledComponent():forEach(function(compVillager)
                                            cVillager = cVillager + 1
                                            if (cVillager == xVillager) then -- delete them
                                                compVillager:getOwner():destroyAllChild()
                                                compVillager:getOwner():destroy()
                                            end
                                        end)
                                    end

                                    bCondition = true 

                                end
                            end)
                        end

                        -- Flying Sparks
                        if (xEvent == 42 and iVillager > 100) then 

                            -- Count the houses
                            iHouse = 0
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "HOUSE") then 
                                    iHouse = iHouse + 1
                                end
                            end)

                            if (iHouse > 0) then

                                -- Burn down the houses
                                cHouse = 0
                                xHouse = math.random(1, iHouse)
                                self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding1)
                                    if (tostring(compBuilding1.AssetBuilding.Name) == "HOUSE") then 
                                        cHouse = cHouse + 1
                                        if (xHouse == cHouse) then
                                            local pos1 = compBuilding1:getOwner():getGlobalPosition()
                                            -- mod:log("Pos1 = " .. tostring(pos1))

                                            local objlist = {}

                                            -- Find any other building within x metres
                                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding2)
                                                if (tostring(compBuilding2.AssetBuilding.Name) == "HOUSE") then 
                                                    local pos2 = compBuilding2:getOwner():getGlobalPosition()
                                                    -- mod:log("Pos2 = " .. tostring(pos2))
                                                    local distance = math.sqrt( (pos1.x - pos2.x)^2 + (pos1.z - pos2.z)^2 )
                                                    -- mod:log("Dist = " .. tostring(distance))
                                                    if (distance <= 30) then
                                                        -- insert the house ID into the table
                                                        table.insert(objlist, 1, compBuilding2:getOwner():getId())
                                                    end
                                                end
                                            end)

                                            -- Find any tree within x metres
                                            self:getLevel():getComponentManager("COMP_TREE"):getAllEnabledComponent():forEach(function(compTree)
                                                local pos2 = compTree:getOwner():getGlobalPosition()
                                                -- mod:log("Pos2 = " .. tostring(pos2))
                                                local distance = math.sqrt( (pos1.x - pos2.x)^2 + (pos1.z - pos2.z)^2 )
                                                -- mod:log("Dist = " .. tostring(distance))
                                                if (distance <= 30) then
                                                    -- insert the tree ID into the table
                                                    table.insert(objlist, 1, compTree:getOwner():getId())
                                                end
                                            end)
                                            
                                            -- Destroy the nearby houses and trees
                                            if (#objlist > 0) then
                                                local iObj = #objlist
                                                for i=1, iObj, 1 do
                                                    local objtarget = self:getLevel():find(tostring(objlist[i]))
                                                    if (objtarget) then 
                                                        objtarget:destroy() 
                                                        -- mod:log("House destroyed.")
                                                    end
                                                end
                                            end

                                            bCondition = true 
                                        end
                                    end
                                end)
                            end
                        end

                        -- Blacksmith accident
                        if (xEvent == 43) then 
                            -- Check that blacksmith is built
                            bFound = false
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "BLACKSMITH") then bFound = true end
                            end)

                            xVillager = 0
                            if (bFound) then
                                self:getLevel():getComponentManager("COMP_VILLAGER"):getAllEnabledComponent():forEach(function(compVillager)
                                    local compJob = compVillager:getAssetJob()
                                    if (compJob and xVillager == 0) then
                                        if (tostring(compJob.JobName) == "JOB_BLACKSMITH") then
                                            compVillager:getOwner():destroyAllChild()
                                            compVillager:getOwner():destroy()
                                            xVillager = 1
                                            bCondition = true 
                                        end
                                    end
                                end)
                            end
                        end

                        -- Gatherers leave
                        if (xEvent == 44) then 
                            -- Check that gathering hut is built
                            bFound = false
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "GATHERING_HUT") then bFound = true end
                            end)

                            if (bFound) then
                                self:getLevel():getComponentManager("COMP_VILLAGER"):getAllEnabledComponent():forEach(function(compVillager)
                                    local compJob = compVillager:getAssetJob()
                                    if (compJob) then
                                        if (tostring(compJob.JobName) == "GATHERER") then
                                            if (math.random() <= 0.5) then
                                                compVillager:getOwner():destroyAllChild()
                                                compVillager:getOwner():destroy()
                                            end
                                        end
                                    end
                                end)
                                bCondition = true 
                            end
                        end

                        -- Sheep run amok
                        if (xEvent == 45) then 
                            -- Check that sheep farm is built
                            aFound = false
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "SHEEP_FARM") then aFound = true end
                            end)

                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (tostring(compBuilding.AssetBuilding.Name) == "SHEEP_FARM") then
                                
                                    objlist = {}
                                    local pos1 = compBuilding:getOwner():getGlobalPosition()

                                    self:getLevel():getComponentManager("COMP_RESOURCE_CONTAINER"):getAllEnabledComponent():forEach(function(compContainer)
                                        local compName = compContainer.ResourceData.ResourceName
                                        if (compName) then
                                            if (tostring(compName) == "BERRIES") then
                                                local pos2 = compContainer:getOwner():getGlobalPosition()
                                                local distance = math.sqrt( (pos1.x - pos2.x)^2 + (pos1.z - pos2.z)^2 )
                                                if (distance <= 100) then
                                                    -- insert the object ID into the table
                                                    table.insert(objlist, 1, compContainer:getOwner():getId())
                                                end
                                            end
                                        end
                                    end)

                                    -- Destroy the berry bushes
                                    if (#objlist > 0) then
                                        local iObj = #objlist
                                        for i=1, iObj, 1 do
                                            local objtarget = self:getLevel():find(tostring(objlist[i]))
                                            if (objtarget) then 
                                                objtarget:destroy() 
                                            end
                                        end
                                    end

                                    bCondition = true 

                                end
                            end)
                        end

                        -- Too many candles
                        if (xEvent == 46) then 
                            -- Count the churches
                            iChurch = 0
                            self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                if (string.find(string.upper(tostring(compBuilding.AssetBuilding.Name)), "CHURCH")) then 
                                    iChurch = iChurch + 1
                                    bCondition = true 
                                end
                            end)

                            if (iChurch > 0) then
                                cChurch = math.random(1, iChurch)
                                xChurch = 0
                                objlist = {}
                                self:getLevel():getComponentManager("COMP_BUILDING"):getAllEnabledComponent():forEach(function(compBuilding)
                                    if (string.find(string.upper(tostring(compBuilding.AssetBuilding.Name)), "CHURCH")) then 
                                        xChurch = xChurch + 1
                                        if (xChurch == cChurch) then
                                            table.insert(objlist, 1, compBuilding:getOwner():getId())
                                        end
                                    end
                                end)


                                -- Destroy the church
                                if (#objlist > 0) then
                                    local iObj = #objlist
                                    for i=1, iObj, 1 do
                                        local objtarget = self:getLevel():find(tostring(objlist[i]))
                                        if (objtarget and not objtarget:getComponent("COMP_BUILDING").EditMode) then 
                                            objtarget:destroy() 
                                            bCondition = true 
                                        end
                                    end
                                end
                            end
                        end

                        -- Exodus
                        if (xEvent == 47 and iVillager >= 100) then 
                            objlist = {}
                            self:getLevel():getComponentManager("COMP_VILLAGER"):getAllEnabledComponent():forEach(function(compVillager)
                                if (math.random() < 0.075) then
                                    table.insert(objlist, 1, compVillager:getOwner():getId())
                                end
                            end)
                            -- Destroy the villagers
                            if (#objlist > 0) then
                                local iObj = #objlist
                                for i=1, iObj, 1 do
                                    local objtarget = self:getLevel():find(tostring(objlist[i]))
                                    if (objtarget) then 
                                        objtarget:destroyAllChild() 
                                        objtarget:destroy() 
                                    end
                                end
                            end
                            bCondition = true 
                        end

                        

                        -- Run event if conditions met
                        if (bCondition) then

                            -- Find the first villager you can use to trigger the event/quest
                            local compVillager = self:getLevel():find("COMP_VILLAGER", true)
                            local compJob = compVillager:getAssetJob()
                            local compJobInstance = compVillager:getJobInstance()
                            if (compJobInstance) then
                                local compJobWorkplace = compJobInstance.Workplace
                            else
                                local compJobWorkplace = ""
                            end        

                            -- Trigger the event by momentarily changing the villager's job, and then back to the old job
                            compVillager:changeJob("JOB_TAS_EVENT_" .. tEvent)
                            compVillager:changeJob(compJob, compJobWorkplace)

                            -- Mark the event as having been selected today, so that it cannot be picked again for another year
                            compEvent.EventTracker[xEvent][2] = self.DaysFromStart

                            -- Mark that you have run an event today
                            compEvent.DayLastEvent = self.DaysFromStart

                        end -- only run if specific conditions are met per event

                    end -- this event did not occur in the last year

                end -- an event will be run (random chance)
            
            end -- event was not run in the last 28 days

        end -- compEvent was found

        -- End Events ------------------------------------------------------------------------------------------------------------------------------


    end) -- on new day end

end -- component init end



-- Register custom Class
mod:registerClass(COMP_TAS_CALENDAR)



-- Attach class to the prefab manager which means it will be present in the game from the beginning
mod:registerPrefabComponent("PREFAB_MANAGER", { DataType = "COMP_TAS_CALENDAR" } )